@@ -37,14 +37,6 @@ static struct termios saved_tty;
 # define	put_str		addstr
 # endif
 
-#if !defined(BSD_RELEASE) || BSD_RELEASE < 44
-extern int	_putchar();
-#endif
-
-#ifdef linux
-  #define	_puts(s)	tputs(s, 0, _putchar)
-#endif
-
 FLAG	Last_player = FALSE;
 # ifdef MONITOR
 FLAG	Am_monitor = FALSE;
